@@ -107,7 +107,7 @@ compare.evol.rates<-function(A,phy,gp,iter=999,seed=NULL,method=c("simulation","
     diag(rate.mat)<-sigma.obs$sigma.d.all
     rate.mat<-makePD(rate.mat)
     x.sim<-simplify2array(sim.char.BM(phy=phy,par=rate.mat,nsim=iter, seed=seed)) 
-    x.r <- simplify2array(lapply(1:iter, function(j) Ptrans%*%x.sim[,,1]))
+    x.r <- simplify2array(lapply(1:iter, function(j) Ptrans%*%x.sim[,,j]))
   }
   if(method == "permutation"){
     ind<-perm.index(N,iter, seed=seed)
